@@ -4,7 +4,7 @@ from .func import reduce_dict_by, summarize_dict_by, generate_inf_seq, compose,
     with_printed_shape, is_bad_num, ifelse
 from .type import ModuleFactory, Shape, Device
 from .configuration import Configuration
-from .string_getter import activation_getter, loss_getter
+from .string_getter import get_activation, get_loss
 
 Rearrange = _Rearrange
 
@@ -23,7 +23,7 @@ __all__ = [
     "Shape",
     "Device",
     "Configuration",
-    "activation_getter",
-    "loss_getter",
+    "get_activation",
+    "get_loss",
     "Rearrange",
 ]
\ No newline at end of file
